{$I CTSWITCH.INC}
unit CtReg;
{
Copyright  1995 by Core Software Limited
Mail
  Postal: 3 Tearne Street, St Johns, Worcester, WR2 6BL, England.
  E'Mail: 100041.3143@compuserve.com

Description
 This unit performs registration of the components in CoreTools for Delphi.
 The file is suppied in Pascal format, so that the user can select which
 components to install and to alter the pallette page on which they
 appear by default.
 Several of the components cannot be removed when installing, CtcBase provides
 the base class used by the other components and must be present, along with
 TAboutInfoPropertyEditor which is the editor for the About property on all
 CoreTool components.
 The components utilise the CoreTools library files, and these should always
 remain together with the component units.

History
Issue Date     Engineer        Description
----- -------- --------------- -----------------------------------------------------
1a    11.06.95 Malcolm Daleb  ORIGINAL
}
interface

procedure Register;

implementation

uses
  Classes,     { Provides TStringList, RegisterComponents procedure }
  DsgnIntf,    { Provides RegisterPropertyEditor procedure }
  SysUtils,    { Provides TFileName class }
  CtlDate,     { Provides TCTDateText & TCtTimeText }
  CtcBase,     { Declares TCoreTool abstract class }
  CtcFBase,    { Declares TCoreFileBase abstract class }
  CtcFile,     { Declares TFileTool class }
  CtcParse,    { Declares TParseTool class }
  CtcScan,     { Declares TScanTool class }
  CtcSerch,    { Declares TSearchTool class }
  CtcSysIn,    { Declares TSysInfoTool class }
  CteAbout,    { Declares TAboutInfoPropertyEditor, always needed }
  CteFileN,    { Declares TFileNamePropertyEditor, can be de-registered. }
  CteSelct,    { Declares TSelectListPropertyEditor, can be de-registered. }
  CteTime,     { Declares TTimeTextProperty editor, can be de-registered. }
  CteDate;     { Declares TDateTextPropertyEditor, can be de-registered. }

{----------------------------------------------------------------------------}
procedure Register;
begin
RegisterComponents('CoreTools', [TFileTool,     { CtFile }
                                 TSearchTool,   { CtSearch }
                                 TScanTool,     { CtScan }
                                 TParseTool,    { CtParse }
                                 TSysInfoTool]);{ CtSysInf }

{ Register the property editor for the TAboutInfo class, always needed. }
RegisterPropertyEditor(TypeInfo(TAboutInfo), TCoreTool, 'About', TAboutInfoPropertyEditor);

{ Register the property editor for the TDateText class.
  This editor can be de-registered without breaking anything. }
RegisterPropertyEditor(TypeInfo(TCtDateText), nil, '', TDateTextPropertyEditor);

{ Register the property editor for the TTimeText class.
  This editor can be de-registered without breaking anything. }
RegisterPropertyEditor(TypeInfo(TCtTimeText), nil, '', TTimeTextPropertyEditor);

{ Register the property editor for the TSelectList class.
  This editor can be de-registered without breaking anything. }
RegisterPropertyEditor(TypeInfo(TSelectList), nil, '', TSelectListPropertyEditor);

{ Register the property editor for the TFileName class, found in SysUtils.
  This editor can be de-registered without breaking anything. }
RegisterPropertyEditor(TypeInfo(TFileName), nil, '', TFileNamePropertyEditor);
end;

end.
